#include <errno.h>
#include <fcntl.h>
#include <stdio.h>
#include <string.h>
#include <linux/cdrom.h>
#include <sys/ioctl.h>
#include <sys/types.h>
#include <sys/stat.h>

int quiet = 0;

void usage() {
	fprintf(stderr, "usage: cdcap [-q] <device file> <--cdr|--cdrw|--dvd|--dvdr|--dvdram>\n");
	exit(-1);
}

void error(char *dev) {
	if (!quiet)
		fprintf(stderr, "%s: %s\n", dev, strerror(errno));
	exit(-1);
}

int main(int argc, char *argv[]) {
	int f;
	unsigned long int stat;
	int retval = 0;

	if (argc < 2)
		usage();

	if (!strcmp(argv[1], "-q")) {
		quiet = 1;
		argv++;
		argc--;
	}

	if (argc < 2)
		usage();

	if ((f = open(argv[1], O_RDONLY|O_NONBLOCK)) == -1)
		error(argv[1]);

	if ((stat = ioctl(f, CDROM_GET_CAPABILITY)) == -1)
		error(argv[1]);

	argc--;

	while (--argc && argv++) {
		retval |= !(strcmp(argv[1], "--cdr")    || (stat & CDC_CD_R));
		retval |= !(strcmp(argv[1], "--cdrw")   || (stat & CDC_CD_RW));
		retval |= !(strcmp(argv[1], "--dvd")    || (stat & CDC_DVD));
		retval |= !(strcmp(argv[1], "--dvdr")   || (stat & CDC_DVD_R));
		retval |= !(strcmp(argv[1], "--dvdram") || (stat & CDC_DVD_RAM));
	}

	return retval;
}
